window.Gleam.initSearch([{"doc":"given","title":"given","content":"# 👇Given for Gleam\n\n[![Package &lt;a href=&quot;https://github.com/inoas/gleam-given/releases&quot;&gt;&lt;img src=&quot;https://img.shields.io/github/release/inoas/gleam-given&quot; alt=&quot;GitHub release&quot;&gt;&lt;/a&gt; Version](https://img.shields.io/hexpm/v/given)](https://hex.pm/packages/given)\n[![Erlang-compatible](https://img.shields.io/badge/target-erlang-b83998)](https://www.erlang.org/)\n[![JavaScript Compatible](https://img.shields.io/badge/target-javascript-f3e155)](https://en.wikipedia.org/wiki/JavaScript)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/given/)\n[![Discord](https://img.shields.io/discord/768594524158427167?label=discord%20chat&amp;amp;color=5865F2)](https://discord.gg/Fm8Pwmy)\n[![CI Test](https://github.com/inoas/gleam-given/actions/workflows/test.yml/badge.svg?branch=main&amp;amp;event=push)](https://github.com/inoas/gleam-given/actions/workflows/test.yml)\n\n&lt;br&gt;\n&lt;br&gt;\n\n&lt;p align=&quot;center&quot;&gt;\n  &lt;img src=&quot;https://raw.githubusercontent.com/inoas/gleam-given/main/given-logo.png&quot; alt=&quot;Given Logo&quot; style=&quot;max-height: 33vh; width: auto; height: auto&quot; width=&quot;480&quot; height=&quot;480&quot;/&gt;\n&lt;/p&gt;\n\n&lt;br&gt;\n\n&lt;p align=&quot;center&quot;&gt;\n  &lt;i&gt;\n    👇Given is a library written in Gleam to make it safe and easy to early return.\n  &lt;/i&gt;\n&lt;/p&gt;\n\n&lt;br&gt;\n&lt;br&gt;\n\n\n## Installation\n\n```sh\ngleam add given@1\n```\n\n## Usage\n\n```gleam\nimport given.{\n  given, given_error_in, given_none_in, given_ok_in, given_some_in, not_given,\n}\nimport gleam/io\nimport gleam/option.{None, Some}\n\npub fn main() {\n  given_example()\n  not_given_example()\n  given_ok_in_example()\n  given_error_in_example()\n  given_some_in_example()\n  given_none_in_example()\n}\n\npub fn given_example() {\n  {\n    let user_understood = False\n    use &lt;- given(user_understood, return: fn() { &quot;💡 Bright!&quot; })\n    // …else user handles case where user did not understand here…\n    &quot;🤯 Woof!&quot;\n  }\n  |&gt; io.debug()\n  // &quot;🤯 Woof!&quot;\n\n  Nil\n}\n\npub fn not_given_example() {\n  {\n    let has_admin_role = True\n    // Fetch this from some database\n    use &lt;- not_given(has_admin_role, return: fn() { &quot;✋ Denied!&quot; })\n    // …else user handles case where they are admin here…\n    &quot;👌 Access granted...&quot;\n  }\n  |&gt; io.debug()\n  // &quot;👌 Access granted...&quot;\n\n  Nil\n}\n\npub fn given_ok_in_example() {\n  {\n    let result = Ok(&quot;Hello Joe!&quot;)\n    use ok_value &lt;- given_ok_in(result, else_return: fn(error_value) {\n      error_value\n    })\n    // …user handles Ok value here…\n    ok_value\n  }\n  |&gt; io.debug()\n  // &quot;Hello Joe!&quot;\n\n  Nil\n}\n\npub fn given_error_in_example() {\n  {\n    let result = Error(&quot;Memory exceeded!&quot;)\n    use error_value &lt;- given_error_in(result, else_return: fn(ok_value) {\n      ok_value\n    })\n    // …user handles Error value here…\n    error_value\n  }\n  |&gt; io.debug()\n  // &quot;Memory exceeded!&quot;\n\n  Nil\n}\n\npub fn given_some_in_example() {\n  {\n    let option = Some(&quot;One Penny&quot;)\n    use some_value &lt;- given_some_in(option, else_return: fn() { &quot;Woof!&quot; })\n    // …user handles Some value here…\n    some_value\n  }\n  |&gt; io.debug()\n  // &quot;One Penny&quot;\n\n  Nil\n}\n\npub fn given_none_in_example() {\n  {\n    let option = None\n    use &lt;- given_none_in(option, else_return: fn(some_value) { some_value })\n    // …user handles None here…\n    &quot;Nothing at all&quot;\n  }\n  |&gt; io.debug()\n  // &quot;Nothing at all&quot;\n\n  Nil\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/given&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"given","title":"given","content":"pub fn given(\n  requirement: Bool,\n  return consequence: fn() -&gt; a,\n  otherwise alternative: fn() -&gt; a,\n) -&gt; a\n ## Examples\n\n \n let user_understood = case int.random(1) {\n   1 -&gt; True\n   _ -&gt; False\n }\n\n use &lt;- given(user_understood, return: fn() { &quot;Great!&quot; })\n // …else handle case where user did not understand here…\n &quot;Woof!&quot;\n \n\nSynonyms:\ngiven.given\ngiven given","url":"given.html#given"},{"doc":"given","title":"given_error_in","content":"pub fn given_error_in(\n  result result: Result(a, b),\n  else_return consequence: fn(a) -&gt; c,\n  otherwise alternative: fn(b) -&gt; c,\n) -&gt; c\n ## Examples\n\n \n use error_value &lt;- given_error_in(result, else_return: fn(ok_value) { &quot;Ok&quot; })\n // …handle Error value here…\n &quot;Error&quot;\n \n\nSynonyms:\ngiven.given_error_in\ngiven given_error_in","url":"given.html#given_error_in"},{"doc":"given","title":"given_none_in","content":"pub fn given_none_in(\n  option option: Option(a),\n  else_return consequence: fn(a) -&gt; b,\n  otherwise alternative: fn() -&gt; b,\n) -&gt; b\n ## Examples\n\n \n use none_value &lt;- given_none_in(option, else_return: fn(some_value) { &quot;Some value&quot; })\n // …handle None value here…\n &quot;None&quot;\n \n\nSynonyms:\ngiven.given_none_in\ngiven given_none_in","url":"given.html#given_none_in"},{"doc":"given","title":"given_ok_in","content":"pub fn given_ok_in(\n  result result: Result(a, b),\n  else_return alternative: fn(a) -&gt; c,\n  otherwise consequence: fn(b) -&gt; c,\n) -&gt; c\n ## Examples\n\n \n use ok_value &lt;- given_ok_in(result, else_return: fn(error_value) { &quot;Error&quot; })\n // …handle Ok value here…\n &quot;Ok&quot;\n \n\nSynonyms:\ngiven.given_ok_in\ngiven given_ok_in","url":"given.html#given_ok_in"},{"doc":"given","title":"given_some_in","content":"pub fn given_some_in(\n  option option: Option(a),\n  else_return consequence: fn() -&gt; b,\n  otherwise alternative: fn(a) -&gt; b,\n) -&gt; b\n ## Examples\n\n \n use some_value &lt;- given_some_in(option, else_return: fn() { &quot;None&quot; })\n // …handle Some value here…\n &quot;Some value&quot;\n \n\nSynonyms:\ngiven.given_some_in\ngiven given_some_in","url":"given.html#given_some_in"},{"doc":"given","title":"not_given","content":"pub fn not_given(\n  requirement: Bool,\n  return consequence: fn() -&gt; a,\n  otherwise alternative: fn() -&gt; a,\n) -&gt; a\n ## Examples\n\n \n let user_understood = case int.random(1) {\n   1 -&gt; True\n   _ -&gt; False\n }\n\n use &lt;- not_given(user_understood, return: fn() { &quot;Woof!&quot; })\n // …else handle case where user understood here…\n &quot;Great!&quot;\n \n\nSynonyms:\ngiven.not_given\ngiven not_given","url":"given.html#not_given"},{"doc":"given","title":"given","content":" This library attempts to make guards:\n\n - Applicable to `Bool`, `Result` and `Option` types.\n - Ergonomic to use by providing ways to handle both branches early.\n - Expressive by making it easy to read through function names and labels.\n - Comprehendable by not having to negate the conditions.\n - Safe to use by not accidentally running discarded branches much like\n   `bool.lazy_guard`.\n","url":"given.html"}]);